@@ -1,4 +1,4 @@
-if [ ! -f /etc/papersize ]
+if [ ! -e /etc/papersize ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/papersize /etc/papersize
